#!/usr/bin/perl

###############################################################################
#                                                                             #
# IPFire.org - A linux based firewall                                         #
# Copyright (C) 2014  IPFire Team  <alexander.marx@ipfire.org>                #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

# enable only the following on debugging purpose
#use warnings;
#use CGI::Carp 'fatalsToBrowser';

require '/var/ipfire/general-functions.pl';
require "${General::swroot}/lang.pl";
require "${General::swroot}/header.pl";

# If no settingsfile till now, create it
unless (-e "${General::swroot}/sendemail/settings")	{ system("touch ${General::swroot}/sendemail/settings"); }

require "/usr/lib/sendemail/sendemail-lib.pl";

#Initialize variables and hashes
my $settingsfile="${General::swroot}/sendemail/settings";
my %settings=();
my %mainsettings=();
my %cgiparams=();
my $errormessage='';

#Read all parameters for site
&Header::getcgihash(\%cgiparams);
&General::readhash("${General::swroot}/main/settings", \%mainsettings);
&General::readhash("/srv/web/ipfire/html/themes/".$mainsettings{'THEME'}."/include/colors.txt", \%color);


#Show Headers
&Header::showhttpheaders();

#ACTIONS
if ($cgiparams{'ACTION'} eq "$Lang::tr{'save'}"){ #SaveButton on configsite
	#Check fields
	if ($cgiparams{'USEMAIL'} eq 'on'){
		$errormessage=&checkmailsettings;
	}else{
		$cgiparams{'txt_mailserver'}='';
		$cgiparams{'txt_mailport'}='';
		$cgiparams{'txt_mailuser'}='';
		$cgiparams{'txt_mailpass'}='';
		$cgiparams{'mail_tls'}='';
		$cgiparams{'txt_mailsender'}='';
		$cgiparams{'txt_recipient'}='';
	}
	if(!$errormessage){
		open (TXT, ">$settingsfile") or die("Could not open settingsfile for sendEmail: $!\n");
		close TXT;
		$settings{'USEMAIL'}	= $cgiparams{'USEMAIL'};
		$settings{'SERVER'}		= $cgiparams{'txt_mailserver'};
		$settings{'PORT'}		= $cgiparams{'txt_mailport'};
		$settings{'USER'}		= $cgiparams{'txt_mailuser'};
		$settings{'PASS'}		= $cgiparams{'txt_mailpass'};
		$settings{'TLS'}		= $cgiparams{'mail_tls'};
		$settings{'SENDER'}		= $cgiparams{'txt_mailsender'};
		$settings{'RECIPIENT'}	= $cgiparams{'txt_recipient'};
		&General::writehash("$settingsfile", \%settings);
	}else{
		$cgiparams{'update'}='on';
		&configsite;
	}
}
if ($cgiparams{'ACTION'} eq "$Lang::tr{'sendemail testmail'}"){ #Testmail button on configsite
	&testmail;
}

#Show site
&General::readhash("$settingsfile", \%settings) if(-f $settingsfile);
&configsite;

#FUNCTIONS
sub configsite{
	#If update set fieldvalues new
	if($cgiparams{'update'} eq 'on'){
		$settings{'USEMAIL'}= 'on';
		$settings{'SERVER'} = $cgiparams{'txt_mailserver'};
		$settings{'PORT'} 	= $cgiparams{'txt_mailport'};
		$settings{'USER'} 	= $cgiparams{'txt_mailuser'};
		$settings{'PASS'} 	= $cgiparams{'txt_mailpass'};
	}
	#find preselections
	$checked{'usemail'}{$settings{'USEMAIL'}}				= 'CHECKED';
	$checked{'mail_tls'}{$settings{'TLS'}}					= 'CHECKED';
	
	#Open site
	&Header::openpage($Lang::tr{'sendemail settings'}, 1, '');
	&Header::openbigbox('100%', 'center');
	&error;
	&info;
	&Header::openbox('100%', 'left', $Lang::tr{'sendemail config'});
	
	#### JAVA SCRIPT ####
	print<<END;
<script>
	\$(document).ready(function() {
		// Show/Hide elements when USEMAIL checkbox is checked.
		if (\$("#MAIL").attr("checked")) {
			\$(".MAILSRV").show();
		} else {
			\$(".MAILSRV").hide();
		}

		// Toggle MAIL elements when "USEMAIL" checkbox is clicked
		\$("#MAIL").change(function() {
			\$(".MAILSRV").toggle();
		});
	});
</script>
END
#######################	
	my $col="style='background-color:$color{'color22'}'";
	print<<END;
	<form method='post' action='$ENV{'SCRIPT_NAME'}'>
	<table style='width:100%' border='0'>
	<tr>
		<th colspan='3'></th>
	</tr>
	<tr>
		<td style='width:24em'>$Lang::tr{'sendemail usemail'}</td>
		<td><label><input type='checkbox' name='USEMAIL' id='MAIL' $checked{'usemail'}{'on'}></label></td>
		<td></td>
	</tr>
	</table><br>

	<div class="MAILSRV">
		<table style='width:100%;'>
		<tr>
			<td style='width:24em'>$Lang::tr{'sendemail mailaddr'}</td>
			<td><input type='text' name='txt_mailserver' value='$settings{'SERVER'}' style='width:22em;'></td>
		</tr>
		<tr>
			<td>$Lang::tr{'sendemail mailport'}</td>
			<td><input type='text' name='txt_mailport' value='$settings{'PORT'}' size='3'></td>
		</tr>
		<tr>
			<td>$Lang::tr{'sendemail mailuser'}<img src='/blob.gif' alt='*' /></td>
			<td><input type='text' name='txt_mailuser' value='$settings{'USER'}' style='width:22em;'></td>
		</tr>
		<tr>
			<td>$Lang::tr{'sendemail mailpass'}<img src='/blob.gif' alt='*' /></td>
			<td><input type='password' name='txt_mailpass' value='$settings{'PASS'}' style='width:22em;' ></td>
		</tr>
		<tr>
			<td>$Lang::tr{'sendemail tls'}</td>
			<td><input type='checkbox' name='mail_tls' $checked{'mail_tls'}{'on'}></td>
		</tr>
		<tr>
			<td>$Lang::tr{'sendemail mailsender'}</td>
			<td><input type='text' name='txt_mailsender' value='$settings{'SENDER'}' style='width:22em;'></td>
		</tr>
		<tr>
			<td>$Lang::tr{'sendemail mailrcpt'}</td>
			<td><input type='text' name='txt_recipient' value='$settings{'RECIPIENT'}' style='width:22em;'></td>
		</tr>
END
		if (! -z $settingsfile && $settings{'USEMAIL'} eq 'on'){
			print "<tr>";
			print "<td></td>";
			print "<td><input type='submit' name='ACTION' value='$Lang::tr{'sendemail testmail'}'></td>";
			print "</tr>";
		}
		print<<END;;
		<tr>
			<td colspan='2'>&nbsp;</td>
		</tr>
		</table>
	</div>

	<table style='width:100%;'>
	<tr>
		<td colspan='3' display:inline align='right'><input type='submit' name='ACTION' value='$Lang::tr{'save'}'></td>
	</tr>
	</table>
	<br>
	</form>
END
	&Header::closebox();
	&Header::closebigbox();	
	&Header::closepage();
	exit 0;
}
sub checkmailsettings{
	#Check if mailserver is an ip address or a domain
	if ($cgiparams{'txt_mailserver'} =~ /^(\d+)\.(\d+)\.(\d+)\.(\d+)$/){
		if (! &General::validip($cgiparams{'txt_mailserver'})){
			$errormessage.="$Lang::tr{'sendemail invalid mailip'} $cgiparams{'txt_mailserver'}<br>";
		}
	}elsif(! &General::validfqdn($cgiparams{'txt_mailserver'})){
			$errormessage.="$Lang::tr{'sendemail invalid mailfqdn'} $cgiparams{'txt_mailserver'}<br>";
	}
	#Check valid mailserverport
	if($cgiparams{'txt_mailport'} < 1 || $cgiparams{'txt_mailport'} > 65535){
		$errormessage.="$Lang::tr{'sendemail invalid mailport'} $cgiparams{'txt_mailport'}<br>";
	}
	#Check valid sender
	if(! $cgiparams{'txt_mailsender'}){
		$errormessage.="$Lang::tr{'sendemail empty field'} $Lang::tr{'sendemail mailsender'}<br>";
	}else{
		if (! &General::validemail($cgiparams{'txt_mailsender'})){
			$errormessage.="<br>$Lang::tr{'sendemail invalid'} $Lang::tr{'sendemail mailsender'}<br>";
		}
	}
	return $errormessage;
}
sub testmail{
	my $res=mail::send_mail("$Lang::tr{'sendemail subject'}", "$Lang::tr{'sendemail text'}");
	if ($res eq 0){
		return $infomessage="$Lang::tr{'sendemail success'}";
	}else{
		return $errormessage="$Lang::tr{'sendemail error'}";
	}
}
sub info{
		if ($infomessage) {
		&Header::openbox('100%', 'left', $Lang::tr{'info messages'});
		print "<class name='base'>$infomessage\n";
		print "&nbsp;</class>\n";
		&Header::closebox();
	}
}
sub error{
	if ($errormessage) {
		&Header::openbox('100%', 'left', $Lang::tr{'error messages'});
		print "<class name='base'>$errormessage\n";
		print "&nbsp;</class>\n";
		&Header::closebox();
	}
}















